==> nextcloud-app-tasks-0.9.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ca.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tasques",
    "Started yesterday" : "Començat ahir",
    "Starts today" : "Començat avui",
    "Starts tomorrow" : "A fer demà",
    "Started on" : "Començat",
    "Starts on" : "Per començar",
    "Yesterday" : "Ahir",
    "Today" : "Avui",
    "Tomorrow" : "Demà",
    "in %s" : "en %s",
    "%s ago" : "%s restants",
    "seconds" : "segons",
    "a minute" : "un minut",
    "%d minutes" : "%d minuts",
    "an hour" : "una hora",
    "%d hours" : "%d hores",
    "a day" : "un dia",
    "%d days" : "%d dies",
    "a month" : "un mes",
    "%d months" : "%d mesos",
    "a year" : "un any",
    "%d years" : "%d anys",
    "week" : "setmana",
    "weeks" : "setmanes",
    "day" : "dia",
    "days" : "dies",
    "hour" : "hora",
    "hours" : "hores",
    "minute" : "minut",
    "minutes" : "minuts",
    "second" : "segon",
    "before beginning" : "abans de començar",
    "before end" : "abans del final",
    "after end" : "Després del final",
    "Comment" : "Comentari",
    "Add a comment" : "Afegeix un comentari",
    "Hidden" : "Ocult",
    "Visible" : "Visible",
    "Automatic" : "Automàtic",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Add an important item in \"%s\"..." : "Afegeix una tasca important a \"%s\"...",
    "Add an item due today in \"%s\"..." : "Afegeix una tasca per avui a \"%s\"...",
    "Add an item in \"%s\"..." : "Afegeix una tasca a \"%s\"...",
    "Add a current item in \"%s\"..." : "Afegeix una tasca actual a \"%s\"...",
    "Add a subtask to \"%s\"..." : "Afegeix una subtasca a \"%s\"...",
    "Hours" : "Hores",
    "Minutes" : "Minuts",
    "%s %% completed" : "%s %% completat",
    "priority %s: " : "prioritat %s:",
    "high" : "alta",
    "medium" : "mitja",
    "Remind me" : "Recorda'm",
    "at the end" : "al final",
    "Set start date" : "Assigna una data d'inici",
    "{calendar} shared by {owner}" : "{calendar} compartit per {owner}",
    "Unnamed" : "Sense nom",
    "Important" : "Important",
    "Week" : "Setmana",
    "All" : "Tots",
    "Current" : "Actual",
    "Completed" : "Completat",
    "Delete" : "Esborra",
    "Cancel" : "Cancel·lar",
    "Edit" : "Editar",
    "Link" : "Enllaç",
    "Download" : "Descàrrega",
    "Save" : "Desar",
    "Add List..." : "Afegeix Llista...",
    "New List" : "Nova llista",
    "Settings" : "configuració",
    "Start of week" : "Començament de setmana",
    "Change sort order" : "Canvia l'ordre",
    "Default" : "Per defecte",
    "Start date" : "Data d'inici",
    "Priority" : "Prioritat",
    "Alphabetically" : "Alfabèticament",
    "Manually" : "Manual",
    "Load remaining completed tasks." : "Carrega les tasques acabades restants.",
    "All day" : "Tot el dia",
    "(New category)" : "(Nova categoria)",
    "Select categories..." : "Selecciona categories...",
    "Loading the task..." : "Carregant la tasca...",
    "Task not found!" : "La tasca no s'ha trobat!",
    "add a subtask to" : "afegeix una subtasca a"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-app-tasks-0.9.6-2-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/tasks/l10n/ca.js <==
OC.L10N.register(
    "tasks",
    {
    "Tasks" : "Tasques",
    "Due yesterday" : "Per ahir",
    "Due today" : "Per avui",
    "Due tomorrow" : "Per demà",
    "Due on" : "Per a",
    "Started yesterday" : "Començat ahir",
    "Starts today" : "Començat avui",
    "Starts tomorrow" : "A fer demà",
    "Started on" : "Començat",
    "Starts on" : "Per començar",
    "[Remind me yesterday at ]HH:mm" : "[Recorda'm ahir a] HH: mm",
    "[Remind me today at ]HH:mm" : "[Recorda'm avui a] HH: mm",
    "[Remind me tomorrow at ]HH:mm" : "[Recorda'm demà a] HH: mm",
    "[Remind me on ]MMM DD, YYYY,[ at ]HH:mm" : "[Recordeu-me] MMM DD, YYYY, [at] HH: mm",
    "Yesterday" : "Ahir",
    "Today" : "Avui",
    "Tomorrow" : "Demà",
    "in %s" : "en %s",
    "%s ago" : "%s restants",
    "seconds" : "segons",
    "a minute" : "un minut",
    "%d minutes" : "%d minuts",
    "an hour" : "una hora",
    "%d hours" : "%d hores",
    "a day" : "un dia",
    "%d days" : "%d dies",
    "a month" : "un mes",
    "%d months" : "%d mesos",
    "a year" : "un any",
    "%d years" : "%d anys",
    "week" : "setmana",
    "weeks" : "setmanes",
    "day" : "dia",
    "days" : "dies",
    "hour" : "hora",
    "hours" : "hores",
    "minute" : "minut",
    "minutes" : "minuts",
    "second" : "segon",
    "before beginning" : "abans de començar",
    "after beginning" : "després de començar",
    "before end" : "abans del final",
    "after end" : "Després del final",
    "Comment" : "Comentari",
    "Add a comment" : "Afegeix un comentari",
    "This will delete the Calendar \"%s\" and all of its entries." : "Eliminarà el calendari \"%s\" i totes les seves entrades.",
    "The name \"%s\" is already used." : "El nom \"%s\" ja està usat",
    "An empty name is not allowed." : "No es permet compartir de nou",
    "Hidden" : "Ocult",
    "Visible" : "Visible",
    "Automatic" : "Automàtic",
    "Sunday" : "Diumenge",
    "Monday" : "Dilluns",
    "Tuesday" : "Dimarts",
    "Wednesday" : "Dimecres",
    "Thursday" : "Dijous",
    "Friday" : "Divendres",
    "Saturday" : "Dissabte",
    "Add an important item in \"%s\"..." : "Afegeix una tasca important a \"%s\"...",
    "Add an item due today in \"%s\"..." : "Afegeix una tasca per avui a \"%s\"...",
    "Add an item in \"%s\"..." : "Afegeix una tasca a \"%s\"...",
    "Add a current item in \"%s\"..." : "Afegeix una tasca actual a \"%s\"...",
    "Add a subtask to \"%s\"..." : "Afegeix una subtasca a \"%s\"...",
    "_%n Completed Task_::_%n Completed Tasks_" : ["%n Tasca Completada","%n Tasques Completades"],
    "Hours" : "Hores",
    "Minutes" : "Minuts",
    "Set due date" : "Estableix la data de venciment",
    "%s %% completed" : "%s %% completat",
    "priority %s: " : "prioritat %s:",
    "high" : "alta",
    "medium" : "mitja",
    "low" : "baixa",
    "no priority assigned" : "sense prioritat assignada",
    "Remind me" : "Recorda'm",
    "at the end" : "al final",
    "at the beginning" : "al començament",
    "Set start date" : "Assigna una data d'inici",
    "{calendar} shared by {owner}" : "{calendar} compartit per {owner}",
    "Unnamed" : "Sense nom",
    "Important" : "Important",
    "Week" : "Setmana",
    "All" : "Tots",
    "Current" : "Actual",
    "Completed" : "Completat",
    "Delete" : "Esborra",
    "Cancel" : "Cancel·lar",
    "Edit" : "Editar",
    "Link" : "Enllaç",
    "Download" : "Descàrrega",
    "Save" : "Desar",
    "Add List..." : "Afegeix Llista...",
    "New List" : "Nova llista",
    "Settings" : "configuració",
    "Start of week" : "Començament de setmana",
    "Visibility of Smart Collections" : "Visibilitat de les col·leccions intel·ligents",
    "Change sort order" : "Canvia l'ordre",
    "Default" : "Per defecte",
    "Due date" : "Per la data",
    "Start date" : "Data d'inici",
    "Priority" : "Prioritat",
    "Alphabetically" : "Alfabèticament",
    "Manually" : "Manual",
    "Load remaining completed tasks." : "Carrega les tasques acabades restants.",
    "Task is completed" : "Completat",
    "All day" : "Tot el dia",
    "(New category)" : "(Nova categoria)",
    "Select categories..." : "Selecciona categories...",
    "Loading the task..." : "Carregant la tasca...",
    "Task not found!" : "La tasca no s'ha trobat!",
    "add a subtask to" : "afegeix una subtasca a",
    "Toggle subtasks" : "Canviar compartició",
    "Toggle completed subtasks" : "Carrega les tasques acabades restants."
},
"nplurals=2; plural=(n != 1);");
